==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/SummaryDataDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SummaryDataDescription } from "./SummaryDataDescription";
/**
 * @hidden
 */
export let SummaryDataDescriptionMetadata = /*@__PURE__*/ (() => {
    class SummaryDataDescriptionMetadata extends Base {
        static b(a) {
            if (SummaryDataDescriptionMetadata.a == null) {
                SummaryDataDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SummaryDataDescriptionMetadata.c(SummaryDataDescriptionMetadata.a);
            }
            if (a.j(SummaryDataDescriptionMetadata.a)) {
                return;
            }
            a.y(SummaryDataDescriptionMetadata.a);
        }
        static c(a) {
            a.item("SummaryName", "String");
            a.item("SummaryValueRef", "(w:SummaryValue,wf:SummaryValue)DataRef");
            a.item("SummaryOperand", "ExportedType:string:DataSourceSummaryOperand");
            a.item("SummaryOperand@names", "Min;Max;Sum;Average;Count;Custom");
            a.item("FormattedText", "String");
            a.item("FormattedValue", "String");
        }
        static d(a) {
            SummaryDataDescriptionMetadata.b(a);
            a.aa("SummaryData", () => new SummaryDataDescription());
            a.z("SummaryData", SummaryDataDescriptionMetadata.a);
        }
    }
    SummaryDataDescriptionMetadata.$t = /*@__PURE__*/ markType(SummaryDataDescriptionMetadata, 'SummaryDataDescriptionMetadata');
    SummaryDataDescriptionMetadata.a = null;
    return SummaryDataDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/SummaryDataDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SummaryDataDescription } from "./SummaryDataDescription";
/**
 * @hidden
 */
export let SummaryDataDescriptionMetadata = /*@__PURE__*/ (() => {
    class SummaryDataDescriptionMetadata extends Base {
        static b(a) {
            if (SummaryDataDescriptionMetadata.a == null) {
                SummaryDataDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SummaryDataDescriptionMetadata.c(SummaryDataDescriptionMetadata.a);
            }
            if (a.k(SummaryDataDescriptionMetadata.a)) {
                return;
            }
            a.aa(SummaryDataDescriptionMetadata.a);
        }
        static c(a) {
            a.item("SummaryName", "String");
            a.item("SummaryValueRef", "(w:SummaryValue,wf:SummaryValue)DataRef");
            a.item("SummaryOperand", "ExportedType:string:DataSourceSummaryOperand");
            a.item("SummaryOperand@names", "Min;Max;Sum;Average;Count;Custom");
            a.item("FormattedText", "String");
            a.item("FormattedValue", "String");
        }
        static d(a) {
            SummaryDataDescriptionMetadata.b(a);
            a.ac("SummaryData", () => new SummaryDataDescription());
            a.ab("SummaryData", SummaryDataDescriptionMetadata.a);
        }
    }
    SummaryDataDescriptionMetadata.$t = /*@__PURE__*/ markType(SummaryDataDescriptionMetadata, 'SummaryDataDescriptionMetadata');
    SummaryDataDescriptionMetadata.a = null;
    return SummaryDataDescriptionMetadata;
})();
